@@ -430,41 +430,10 @@ class Catalog:
         """
         content = (kw.pop("_content", kw.pop("__content", "")) or "").strip()
         attrs = kw.pop("_attrs", kw.pop("__attrs", None)) or {}
-        source = kw.pop("_source", kw.pop("__source", ""))
-        file_ext = kw.pop("_file_ext", kw.pop("__file_ext", "")) or self.file_ext
-        caller_prefix = kw.pop("__prefix", "")
-
-        cname = __name
-        prefix, name = self._split_name(cname)
-        component = None
-
-        if source:
-            logger.debug("Rendering from source %s", cname)
-            self.jinja_env.loader = self.prefixes[prefix]
-            component = self._get_from_source(prefix=prefix, name=name, source=source)
-        else:
-            logger.debug("Rendering from cache or file %s", cname)
-            get_from = self._get_from_cache if self.use_cache else self._get_from_file
-
-            if caller_prefix:
-                self.jinja_env.loader = self.prefixes[caller_prefix]
-                component = get_from(
-                    prefix=caller_prefix,
-                    name=cname,
-                    file_ext=file_ext
-                )
-            if not component:
-                self.jinja_env.loader = self.prefixes[prefix]
-                component = get_from(
-                    prefix=prefix,
-                    name=name,
-                    file_ext=file_ext
-                )
-
-        if not component:
-            raise ComponentNotFound(cname, file_ext)
 
+        component = self._get_component(__name, **kw)
         root_path = component.path.parent if component.path else None
+
         # Get current assets lists
         css_list = self.collected_css
         js_list = self.collected_js
@@ -633,6 +602,39 @@ class Catalog:
 
         return f"{parent}{stem}-{fingerprint}{ext}"
 
+    def _get_component(self, cname: str, **kw) -> Component:
+        source = kw.pop("_source", kw.pop("__source", ""))
+        file_ext = kw.pop("_file_ext", kw.pop("__file_ext", "")) or self.file_ext
+        caller_prefix = kw.pop("__prefix", "")
+
+        prefix, name = self._split_name(cname)
+        component = None
+
+        if source:
+            logger.debug("Rendering from source %s", cname)
+            self.jinja_env.loader = self.prefixes[prefix]
+            return self._get_from_source(prefix=prefix, name=name, source=source)
+
+        logger.debug("Rendering from cache or file %s", cname)
+        get_from = self._get_from_cache if self.use_cache else self._get_from_file
+        if caller_prefix:
+            self.jinja_env.loader = self.prefixes[caller_prefix]
+            component = get_from(
+                prefix=caller_prefix,
+                name=cname,
+                file_ext=file_ext
+            )
+        if not component:
+            self.jinja_env.loader = self.prefixes[prefix]
+            component = get_from(
+                prefix=prefix,
+                name=name,
+                file_ext=file_ext
+            )
+        if component:
+            return component
+        raise ComponentNotFound(cname, file_ext)
+
     def _get_from_source(
         self,
         *,
@@ -706,9 +708,7 @@ class Catalog:
         root_paths = self.prefixes[prefix].searchpath
 
         name = name.replace(DELIMITER, SLASH)
-        name_path = Path(name)
-        kebab_stem = kebab_case(name_path.stem)
-        kebab_name = str(name_path.with_name(kebab_stem))
+        kebab_name = kebab_case(name)
         dot_names = (f"{name}.", f"{kebab_name}.")
 
         for root_path in root_paths:
@@ -716,7 +716,10 @@ class Catalog:
                 root_path, topdown=False, followlinks=True
             ):
                 relfolder = os.path.relpath(curr_folder, root_path).strip(".")
-                if relfolder and not name.startswith(relfolder):
+                if relfolder and not (
+                    name.startswith(relfolder)
+                    or kebab_name.startswith(relfolder)
+                ):
                     continue
 
                 for filename in files:
@@ -724,6 +727,7 @@ class Catalog:
                         filepath = f"{relfolder}/{filename}"
                     else:
                         filepath = filename
+
                     if filepath.startswith(dot_names) and filepath.endswith(file_ext):
                         return Path(curr_folder) / filename, Path(filepath)
 
